<!DOCTYPE html>
<html lang="{{ page.lang | default: site.lang | default: "en" }}">

  {%- include head.html -%}

  <body class="d-flex flex-column min-vh-100">
    <script src="{{ "/assets/js/color_mode.js" | relative_url }}"></script>

    {%- include header.html -%}

    {{ content }}

    {%- include footer.html -%}

  </body>

</html>