<meta charset="utf-8">
<meta lang="{{ page.lang | default: site.lang | default: "en" }}">
<link rel="shortcut icon" href="{{ "/assets/logo.ico" | relative_url }}" type="image/x-icon">
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
<link rel="stylesheet" title="hljs-default" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.9.0/styles/default.min.css">
<link rel="alternate stylesheet" title="hljs-light" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.9.0/styles/atom-one-light.min.css" disabled="disabled">
<link rel="alternate stylesheet" title="hljs-dark" href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.9.0/styles/atom-one-dark.min.css" disabled="disabled">
<link rel="stylesheet" href="{{ "/assets/css/global.css" | relative_url }}">
{% if page.style %}
<link rel="stylesheet" href="{{ page.style | relative_url }}">
{% endif %}
{% seo %}
<meta name="viewport" content="width=device-width, initial-scale=1">